import { scaleOrdinal } from "d3";

const colorScale = scaleOrdinal()
	.domain(["apple", "lemon"])
	.range(["#fa5a6d", "#fff959"]);

const radiusScale = scaleOrdinal()
	.domain(["apple", "lemon"])
	.range([50, 30] ); 

const xPosition = (d, i) => i * 120;
         
export const fruitBowl = (selection, props) => {
  const { fruits, height } = props;

  const groups = selection.selectAll("g")
  	.data(fruits, d => d.id); 
  const groupsEnter = groups.enter().append("g");
  groupsEnter
    .merge(groups)
  		.attr("transform", (d, i) => 
          `translate(${ 60 }, ${height /2})` 
        	)
	groups.exit()
    .remove();
    
  const circleG = groupsEnter.append("circle")
  		.attr("r", 0)
  		.attr("cx", xPosition)
  	.merge(groups.select("circle"))
      .attr("fill", d => colorScale(d.type)) 
  	.transition().duration(1000)
  		.attr("cx", xPosition)
    	.attr("r", d => radiusScale(d.type));
  
  const textG = groupsEnter.append("text") 
  		.text(d => d.type)
  		.attr("x", (d, i) => i * 120)
  		.attr("y", 80)
  	.merge(groups.select("text"))
  	.transition().duration(1000)
      .text(d => d.type)
  		.attr("x", (d, i) => i *120)
  		.attr("y", 80);
};